<?php
/**
 * Zeen retina image
 *
 * @since 1.0.0
 *
 * @see WP_Widget
 */
class ZeenEngineRetinaImage extends WP_Widget {

	/**
	 * Sets up a new widget instance.
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function __construct() {
		$widget_ops = array(
			'classname' => 'zeen_retina_image',
			'description' => esc_html__( 'Add a retina-ready image with optional link.', 'zeen-engine' ),
			'customize_selective_refresh' => true,
		);

		parent::__construct( 'zeen_retina_image', esc_html__( 'Zeen: Retina Image', 'zeen-engine' ), $widget_ops );

	}

	/**
	 * Outputs the content for the current widget instance.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @param array $args     Display arguments including 'before_title', 'after_title',
	 *                        'before_widget', and 'after_widget'.
	 * @param array $instance Settings for the current widget instance.
	 */
	public function widget( $args, $instance ) {

		/** This filter is documented in wp-includes/widgets/class-wp-widget-pages.php */
		$title                          = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );
		$url                            = ! empty( $instance['url'] ) ? $instance['url'] : '';
		$retina_url                     = ! empty( $instance['retina_url'] ) ? $instance['retina_url'] : '';
		$alt                            = ! empty( $instance['alt'] ) ? $instance['alt'] : '';
		$link                           = ! empty( $instance['link'] ) ? $instance['link'] : '';
		$nofollow                       = ! empty( $instance['nofollow'] ) ? '1' : '0';
		$new_window                     = ! empty( $instance['new_window'] ) ? '1' : '0';
		$output                         = array();

		if ( empty( $url ) && empty( $retina_url ) ) {
			return;
		}
		echo $args['before_widget'];
		if ( ! empty( $title ) ) {
			echo $args['before_title'] . $title . $args['after_title'];
		} 
		?>
		<div class="retina-image">
			<?php if ( $link != '' ) { ?>
				<a href="<?php echo esc_url( $link ); ?>" <?php if ( $new_window == 1 ) {?>target="_blank"<?php } ?><?php if ( $nofollow == 1 ) {?>rel="nofollow"<?php } ?>>
			<?php } ?>
			<img src="<?php echo esc_url( $url); ?>" <?php if ( $retina_url ) { echo 'srcset="' . esc_url( $retina_url ) . ' 2x" '; } ?>alt="<?php echo esc_attr( $alt ); ?>">
			<?php if ( $link != '' ) { ?>
				</a>
			<?php } ?>
		</div>

		<?php
		echo $args['after_widget'];

	}

	/**
	 * Handles updating settings for the current widget instance.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @param array $new_instance New settings for this instance as input by the user via
	 *                            WP_Widget::form().
	 * @param array $old_instance Old settings for this instance.
	 * @return array Settings to save or bool false to cancel saving.
	 */
	public function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title']      = sanitize_text_field( $new_instance['title'] );
		$instance['url']   = esc_url( $new_instance['url'] );
		$instance['retina_url']   = esc_url( $new_instance['retina_url'] );
		$instance['link']   = esc_url( $new_instance['link'] );
		$instance['alt']   = sanitize_text_field( $new_instance['alt'] );
		$instance['nofollow'] = $new_instance['nofollow'] ? 1 : 0;
		$instance['new_window'] = $new_instance['new_window'] ? 1 : 0;

		return $instance;
	}

	/**
	 * Outputs the widget settings form.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @param array $instance Current settings.
	 */
	public function form( $instance ) {
		$instance   = wp_parse_args( (array) $instance, array( 'title' => '', 'url' => '', 'retina_url' => '', 'link' => '', 'alt' => '', 'new_window' => 1, 'nofollow' => 0 ) );
		$id_img = 'zeen-engine-img-' . mt_rand( 1000, 99999 );
		$id_retina = 'zeen-engine-retina-' . mt_rand( 1000, 99999 );
		?>
		<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php esc_html_e( 'Title', 'zeen-engine' ); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr( sanitize_text_field( $instance['title'] ) ); ?>" /></p>
   
		<p id="<?php echo esc_attr( $id_img ); ?>" class="zeen-engine-image-wrap zeen-engine-image-wrap-widget">
			<label for="<?php echo esc_attr( $this->get_field_id('url') ); ?>">
				<?php esc_html_e( 'Image', 'zeen-engine' ); ?>
			</label>
			<span class="zeen-engine-control-only">
				<input id="<?php echo esc_attr( $this->get_field_id('url') ); ?>" name="<?php echo esc_attr( $this->get_field_name('url') ); ?>" type="text" value="<?php echo esc_url( $instance['url'] ); ?>" class="widefat zeen-engine-img-input zeen-engine-input-val">

				<a href="#" class="zeen-engine-upload" data-dest="<?php echo esc_attr( $id_img ); ?>" data-output="src" data-file-type="video" data-name="<?php echo esc_attr( $this->get_field_name('url') ); ?>"><?php esc_html_e( 'Upload', 'zeen-engine' ); ?></a>

			</span>
		</p>
		
		<p id="<?php echo esc_attr( $id_retina ); ?>" class="zeen-engine-image-wrap zeen-engine-image-wrap-widget">
			<label for="<?php echo esc_attr( $this->get_field_id('retina_url') ); ?>">
				<?php esc_html_e( 'Image (Retina)', 'zeen-engine' ); ?>
			</label>
			<span class="zeen-engine-control-only">
				<input id="<?php echo esc_attr( $this->get_field_id('retina_url') ); ?>" name="<?php echo esc_attr( $this->get_field_name('retina_url') ); ?>" type="text" value="<?php echo esc_url( $instance['retina_url'] ); ?>" class="widefat zeen-engine-img-input zeen-engine-input-val">

				<a href="#" class="zeen-engine-upload" data-dest="<?php echo esc_attr( $id_retina ); ?>" data-output="src" data-file-type="video" data-name="<?php echo esc_attr( $this->get_field_name('retina_url') ); ?>"><?php esc_html_e( 'Upload', 'zeen-engine' ); ?></a>

			</span>
		</p>

		<p><label for="<?php echo $this->get_field_id('alt'); ?>"><?php esc_html_e( 'Image Alt Text', 'zeen-engine' ); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id('alt'); ?>" name="<?php echo $this->get_field_name('alt'); ?>" type="text" value="<?php echo esc_attr( $instance['alt'] ); ?>" /><br><small><?php esc_html_e( 'The alt text appears in a blank box that would normally contain the image.', 'zeen-engine' ); ?></small></p>

		<p><label for="<?php echo $this->get_field_id('link'); ?>"><?php esc_html_e( 'Optional Link', 'zeen-engine' ); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id('link'); ?>" name="<?php echo $this->get_field_name('link'); ?>" type="text" value="<?php echo esc_url( $instance['link'] ); ?>" /><br><small><?php esc_html_e( 'Optional link to make image clickable', 'zeen-engine' ); ?></small></p>

		<p>
			<input class="checkbox" type="checkbox"<?php checked( $instance['new_window'] ); ?> id="<?php echo $this->get_field_id('new_window'); ?>" name="<?php echo $this->get_field_name('new_window'); ?>" /> <label for="<?php echo $this->get_field_id('new_window'); ?>"><?php esc_html_e( 'Link opens in new window', 'zeen-engine' ); ?></label></br>
			<input class="checkbox" type="checkbox"<?php checked( $instance['nofollow'] ); ?> id="<?php echo $this->get_field_id('nofollow'); ?>" name="<?php echo $this->get_field_name('nofollow'); ?>" /> <label for="<?php echo $this->get_field_id('nofollow'); ?>"><?php esc_html_e( 'Make the link nofollow', 'zeen-engine' ); ?></label>
		</p>
		<?php
	}
}